@@ -3,7 +3,8 @@ This folder contains helper functions for common mathematical functions.
 Note: this package is not equivalent to PyTorch's functional API, because
 no backwards() methods are provided for these functions!
 
-To use these functions as layers, please use the implementation in layers/ or losses/ instead.
+To use these functions as layers, please use the implementation in
+layers/ or losses/ instead.
 """
 import numpy as np
 
@@ -27,8 +28,3 @@ def sigmoid(x: np.ndarray) -> np.ndarray:
     top = np.ones_like(x)
     top[neg_mask] = z[neg_mask]
     return top / (1 + z)
-
-
-def relu(x: np.ndarray) -> np.ndarray:
-    """ Basic implementation of ReLU function. """
-    return np.maximum(0, x)
